#' @importFrom plotly export
#' @export
plotly::export

#' @importFrom plotly %>%
#' @export
plotly::`%>%`

#' @importFrom plotly subplot
#' @export
plotly::subplot

#' @importFrom plotly plotly_json
#' @export
plotly::plotly_json
